@@ -18,22 +18,24 @@
 """
 Provides location to maintain version information.
 
-@sort: AUTHOR, EMAIL, COPYRIGHT, VERSION, DATE, URL
+Module Attributes
+=================
 
-@var AUTHOR: Author of software.
-@var EMAIL: Email address of author.
-@var COPYRIGHT: Copyright date.
-@var VERSION: Software version.
-@var DATE: Software release date.
-@var URL: URL of Cedar Backup webpage.
+Attributes:
+   AUTHOR: Author of software
+   EMAIL: Email address of author
+   COPYRIGHT: Copyright date
+   VERSION: Software version
+   DATE: Software release date
+   URL: URL of Cedar Backup webpage
 
-@author: Kenneth J. Pronovici <pronovic@ieee.org>
+:author: Kenneth J. Pronovici <pronovic@ieee.org>
 """
 
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2011,2013-2017"
-VERSION     = "3.1.10"
-DATE        = "11 Sep 2017"
+VERSION     = "3.1.12"
+DATE        = "12 Nov 2017"
 URL         = "https://bitbucket.org/cedarsolutions/cedar-backup3"
 
